<?php
// $Id: template.php,v 1.5 2009/03/18 03:41:35 kong Exp $

require_once('theme-settings.inc');

/**
 * Initialize theme settings
 */
if (is_null(theme_get_setting('inf08_wp_readmore_weight'))) {
  inf08_theme_init_settings();
}

function inf08_links($links, $attributes = array('class' => 'links')) {
  $output = '';

  if (count($links) > 0) {
    $output = '<ul'. drupal_attributes($attributes) .'>';

    $num_links = count($links);
    $i = 1;

    foreach ($links as $key => $link) {
      $class = $key;

      // Add first, last and active classes to the list of links to help out themers.
      if ($i == 1) {
        $class .= ' first';
      }
      if ($i == $num_links) {
        $class .= ' last';
      }
      if (isset($link['href']) && ($link['href'] == $_GET['q'] || ($link['href'] == '<front>' && drupal_is_front_page()))) {
        $class .= ' active';
      }
      $output .= '<li'. drupal_attributes(array('class' => $class)) .'>';

      if (isset($link['href'])) {
        $link['title'] = '<span>' . check_plain($link['title']) . '</span>';
        $link['html'] = TRUE;
        // Pass in $link as $options, they share the same keys.
        $output .= l($link['title'], $link['href'], $link);
      }
      else if (!empty($link['title'])) {
        // Some links are actually not links, but we wrap these in <span> for adding title and class attributes
        if (empty($link['html'])) {
          $link['title'] = check_plain($link['title']);
        }
        $span_attributes = '';
        if (isset($link['attributes'])) {
          $span_attributes = drupal_attributes($link['attributes']);
        }
        $output .= '<span'. $span_attributes .'>'. $link['title'] .'</span>';
      }

      $i++;
      $output .= "</li>\n";
    }

    $output .= '</ul>';
  }

  return $output;
}

function phptemplate_preprocess_page(&$vars) {
  if (theme_get_setting('inf08_breadcrumb_display') == 0) {
    $vars['breadcrumb'] = '';
  }

  if (theme_get_setting('toggle_mission') && theme_get_setting('inf08_mission_display') == 'all') {
    $vars['mission'] = variable_get('site_mission', '');
  }

  $vars['mission_title'] = theme_get_setting('inf08_mission_title');

  $vars['main_classes'] = 'with-sidebar';

  // set classes for "main" div
  // if no sidebar content and no search box, expand the main div to full width
  if (empty($vars['sidebar']) && empty($vars['sidebar_left']) && empty($vars['sidebar_right']) && empty($vars['search_box'])) {
    if (empty($vars['mission']) || (!drupal_is_front_page() && (theme_get_setting('inf08_mission_display') == 'front'))) {
      $vars['main_classes'] = 'no-sidebar';
    }
  }

  // prepare variables for footer credits
  $credits['drupal'] = l('Drupal', 'http://drupal.org', array('attributes' => array('title' => 'Official website of Drupal')));
  $credits['inf08'] = l('Inf08', 'http://drupal.org/project/inf08', array('attributes' => array('title' => 'Inf08 theme project page')));
  $credits['original-author'] = l('Inf Design', 'http://www.infscripts.com', array('attributes' => array('title' => 'Free CSS templates')));
  $credits['author'] = l('kong', 'http://suksit.com', array('attributes' => array('title' => 'Suksit Sripitchayaphan')));

  $vars['footer'] .= $credits['inf08'] . ' CSS template by ' . $credits['original-author'] . '. Ported to Drupal by ' . $credits['author'];
}

function phptemplate_preprocess_node(&$vars) {
  // format $submitted
  if (isset($vars['submitted']) && $vars['submitted'] != '') {
    $author = theme('username', $vars['node']);
    $vars['submitted'] = format_date($vars['created'], 'small') . ' / Posted by ' . $author;
  }

  // add "Read the rest of this entry" link
  // to the end of teaser like in WordPress
  if (isset($vars['node']->links['node_read_more'])) {
    $read_more_link = l('Read the rest of this entry' . ' »',
      'node/'. $vars['node']->nid,
      array(
        'attributes' => array(
          'title' => 'Read the rest of "' . $vars['node']->title . '"',
        ),
        'query' => NULL,
        'fragment' => NULL,
        'absolute' => FALSE,
        'html' => TRUE,
      )
    );

    $content = $vars['node']->content;

    $content['read-more'] = array(
      '#weight' => (int)theme_get_setting('inf08_wp_readmore_weight'),
      '#value' => '<p class="read-more">' . $read_more_link . '</p>',
      '#title' => '',
      '#description' => '',
      '#printed' => 1,
    );

    inf08_sort_content($content);

    $vars['content'] = inf08_render_content($content);

    // remove the original "read more" link from $links
    unset($vars['node']->links['node_read_more']);

  }

  // put statistics counter in $node_counter
  if (isset($vars['node']->links['statistics_counter'])) {
    $vars['node_counter'] = $vars['node']->links['statistics_counter']['title'];
    unset($vars['node']->links['statistics_counter']);
  }

  // refresh $links
  $vars['links'] = theme('links', $vars['node']->links, array('class' => 'links inline'));

  // format taxonomy list, code adapted from "Acquia Marina" theme
  if (module_exists('taxonomy')) {
    $vocabularies = taxonomy_get_vocabularies($vars['node']->type);
    $output = '';
    $vocab_delimiter = '';

    $category_content_type = (theme_get_setting('inf08_category_enable_content_type') == 1) ? $vars['node']->type : 'default';
    $category_setting = theme_get_setting('inf08_category_'. $category_content_type);

    foreach ($vocabularies as $vocabulary) {
      $terms = taxonomy_node_get_terms_by_vocabulary($vars['node'], $vocabulary->vid);

      if ($terms) {
        if ($vocabulary->vid != $category_setting) {
          $output .= '<li class="vocab vocab-'. $vocabulary->vid .'"><span class="vocab-name">'. $vocabulary->name .':</span> <span class="vocab-list">';
          $links = array();

          foreach ($terms as $term) {
            $links[] = l($term->name, taxonomy_term_path($term), array('attributes' => array('rel' => 'tag', 'title' => strip_tags($term->description))));
          }

          $output .= implode(", ", $links);
          $output .= '</span></li>';
        }
        // Special case for vocabulary named "Category"
        else {
          $links = array();

          foreach ($terms as $term) {
            $links[] = l($term->name, taxonomy_term_path($term), array('attributes' => array('rel' => 'tag', 'title' => strip_tags($term->description))));
          }

          $category .= implode(", ", $links);
          $vars['category'] = ' in ' . $category;
        }
      }
    }

    if ($output != '') {
      $output = '<ul class="taxonomy">'. $output .'</ul>';
    }

    $vars['terms'] = $output;
  }
  else {
    $vars['terms'] = '';
  }
}

function phptemplate_preprocess_comment_wrapper(&$vars) {
  // get total number of comments
  $comments_count = comment_num_all($vars['node']->nid);

  if ($comments_count == 0) {
    $vars['comments_count'] = 'No comments yet';
  }
  else {
    $vars['comments_count'] = $comments_count . format_plural($comments_count, ' comment', ' comments') . ' on "' . $vars['node']->title . '"';
  }
}

function phptemplate_preprocess_comment(&$vars) {
  // change (not verified) to (visitor)
  $vars['author'] = str_replace('(not verified)', '(visitor)', $vars['author']);

  // format $submitted
  $vars['submitted'] = $vars['author'] . ' said on ' . $vars['date'] . ':';
}

/**
 * Implementation of hook_theme().
 */
function inf08_theme(){
  return array(
    'comment_form' => array(
      'arguments' => array('form' => NULL),
    ),
  );
}

// Theme the comment form
function inf08_comment_form($form) {
  // Add a div wrapper for themeing.
  $form['#prefix'] = '<div id="writecomment">';
  $form['#suffix'] = '</div>';

  return drupal_render($form);
}

/**
 * Returns a formatted list of recent comments to be displayed in the comment block.
 *
 * Override the default number of 10 recent comments
 * and display the configured number of recent comments (default to 5).
 */
function phptemplate_comment_block() {
  $items = array();
  foreach (comment_get_recent(theme_get_setting('inf08_recent_comments')) as $comment) {
    $items[] = l($comment->subject, 'node/'. $comment->nid, array('fragment' => 'comment-'. $comment->cid)) .'<br />'. t('@time ago', array('@time' => format_interval(time() - $comment->timestamp)));
  }
  if ($items) {
    return theme('item_list', $items);
  }
}

function inf08_sort_content(&$content) {
  // sort items in $content according to #weight
  foreach($content as $c) {
     $sort_helper[] = $c['#weight'];
  }

  array_multisort($sort_helper, SORT_ASC, $content);
}

function inf08_render_content($content) {
  // concat everything in $content except #children
  foreach($content as $key => $field) {
    if ($key != '#children') {
      $output .= $field['#value'];
    }
  }

  return $output;
}
